Name:      torque
Version:   1.0.1p6
Release:   ttd5
License:   Open Source
Summary:   Torque, a tera-scale open source resource manager and queing system
Group:     Applications/System
URL:       http://www.supercluster.org/
Vendor:    SuperCluster Group
Packager:  David Groep <davidg@nikhef.nl>
Source0:   torque-1.0.1p6.tar.gz
Source1:   pbs
Patch1:    openpbs-buildroot.patch
Patch2:    torque-1.0.1p6-transient-tmpdir.patch
BuildRoot: /tmp/torque-rpm
requires: /usr/lib/sendmail
Provides: openpbs torque

%description 
Torque is designed for running jobs on one or
more execution hosts, which can be running a variety of operating systems.

%package common
Summary: torque base system and clients
Group: Applications/System
requires: openssh 
buildrequires: openssh
Provides: openpbs-common openpbs torque
%description common
Torque is designed for running jobs on one or
more execution hosts, which can be running a variety of operating systems.

%package mom
Summary: torque exechost (MOM daemon)
Group: Applications/System
requires: openssh openpbs-common
buildrequires: openssh
Provides: openpbs-mom torque-mom
%description mom
Torque MOM daemon and clients, which runs on each machine that will 
run PBS jobs.

%package server
Summary: torque server (server daemon)
Group: Applications/System
requires: openssh openpbs-common psmisc >= 20.0
buildrequires: openssh
Provides: openpbs-server torque-server
%description server
The Torque Server

%package sched
Summary: torque scheduler (sched daemon)
Group: Applications/System
requires: openssh openpbs-common
buildrequires: openssh
Provides: openpbs-sched torque-sched
%description sched
The Torque Scheduler

%prep
%setup -n torque-1.0.1p6
# Apply official PBS patches (if any)
#for pl in 13 14 15; do
#   ${RPM_SOURCE_DIR}/pbs_patch.sh < ${RPM_SOURCE_DIR}/patch_OpenPBS_2.3.$pl
#done

# openpbs-buildroot.patch (fixes "make install" so that it installs into
# our buildroot)
%patch1 -p1

# tmpdir
%patch2 -p1

# Make sure configure is synced with configure.in
#autoconf

%build
PATH=/bin:/usr/bin
export PATH
LD_LIBRARY_PATH=
export LD_LIBRARY_PATH

CFLAGS="-DTRANSIENT_TMPDIR=1"
export CFLAGS
SENDMAIL_CMD="/usr/lib/sendmail"
export SENDMAIL_CMD

./configure --with-scp=/usr/bin/scp --prefix=/usr --enable-gui --set-default_server=localhost --set-server-home=/var/spool/pbs
make

%install
PBS_ROOT=${RPM_BUILD_ROOT}/var/spool/pbs/
RCDIR=${RPM_BUILD_ROOT}/etc/rc.d/

# Standard OpenPBS install (subdir doc/ is seemingly not installed by default)
make DESTDIR=${RPM_BUILD_ROOT} install
cd doc
make DESTDIR=${RPM_BUILD_ROOT} install

# Make server_priv world-executable so that non-root users can get in
# to look at the accounting files
chmod 0751 ${PBS_ROOT}/server_priv

# You probably want to install a more complete MOM configuration here!
# This is also an ideal place to copy custom server/scheduler configuration
# files from ${RPM_SOURCE_DIR} to ${PBS_ROOT}
touch ${PBS_ROOT}/mom_priv/config
echo "localhost" > ${PBS_ROOT}/server_name

# empty nodes set to start with
touch ${PBS_ROOT}/server_priv/nodes

# Install init scripts for server, scheduler and MOM; we make the
# symlinks manually as chkconfig apparently doesn't understand chroot
install -d ${RCDIR}
for init in init.d rc0.d rc1.d rc2.d rc3.d rc4.d rc5.d rc6.d; do
  install -d ${RCDIR}/$init
done
cp ${RPM_SOURCE_DIR}/pbs ${RCDIR}/init.d

# Build tcl indices for xpbsmon and xpbs (have to do this here as it uses
# absolute paths, and gets confused by a buildroot)
XPBSMON_LIB=${RPM_BUILD_ROOT}/usr/lib/xpbsmon
mkdir -p ${XPBSMON_LIB}
cd ${XPBSMON_LIB} && rm -f tclIndex && ./buildindex ${XPBSMON_LIB} && chmod 644 tclIndex
XPBS_LIB=${RPM_BUILD_ROOT}/usr/lib/xpbs
mkdir -p ${XPBS_LIB}
cd ${XPBS_LIB} && rm -f tclIndex && ./buildindex ${XPBS_LIB} && chmod 644 tclIndex

chmod 755 ${RPM_BUILD_ROOT}/usr
chmod 755 ${RPM_BUILD_ROOT}/var
chmod 755 ${RPM_BUILD_ROOT}/var/spool
chmod 755 ${RPM_BUILD_ROOT}/var/spool/pbs
chmod 755 $PBS_ROOT
mkdir $PBS_ROOT/server_priv/jobs
mkdir $PBS_ROOT/server_priv/queues
chmod 750  $PBS_ROOT/server_priv/jobs
chmod 750  $PBS_ROOT/server_priv/queues


%clean
rm -rf ${RPM_BUILD_ROOT}

%post server
# initialise database if not already there
if [ ! -f "${PBS_ROOT}/server_priv/serverdb" ] 
then
  killall -0 pbs_server > /dev/null 2>&1
  if [ $? -eq 0 ]
  then
    echo "serverdb init: PBS server already running, no init performed" >&2
  else
    /usr/sbin/pbs_server -t create
    read pid rest < /var/spool/pbs/server_priv/server.lock
    kill -TERM $pid > /dev/null 2>&1
    /bin/rm -f /var/spool/pbs/server_priv/server.lock
    echo "pbs_server: serverdb created using -t create"
  fi
fi

%files common
%defattr(-,root,root)
/etc/rc.d/init.d/pbs
/usr/bin
/usr/include
/usr/lib
/usr/man
/usr/sbin/pbs_demux
/usr/sbin/pbs_iff
/usr/sbin/pbs_rcp
%config(noreplace) /var/spool/pbs/pbs_environment
%config(noreplace) /var/spool/pbs/server_name
%dir /var/spool/pbs/aux
%dir /var/spool/pbs/checkpoint
%dir /var/spool/pbs/spool

%files server
%defattr(-,root,root)
/usr/sbin/pbs_server
%dir /var/spool/pbs/server_logs
/var/spool/pbs/server_priv

%files sched
%defattr(-,root,root)
/usr/sbin/pbs_sched
%dir /var/spool/pbs/sched_logs
/var/spool/pbs/sched_priv

%files mom
%defattr(-,root,root)
/usr/sbin/pbs_mom
%dir /var/spool/pbs/undelivered
%dir /var/spool/pbs/mom_logs
%dir /var/spool/pbs/mom_priv
%dir /var/spool/pbs/mom_priv/jobs
%config(noreplace) /var/spool/pbs/mom_priv/config

%changelog
